;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "devdocs" "20251022.1255"
  "Emacs viewer for DevDocs."
  '((emacs  "27.1")
    (compat "30.1"))
  :url "https://github.com/astoff/devdocs.el"
  :commit "25c746024ddf73570195bf42b841f761a2fee10c"
  :revdesc "25c746024ddf"
  :keywords '("help")
  :authors '(("Augusto Stoffel" . "arstoffel@gmail.com"))
  :maintainers '(("Augusto Stoffel" . "arstoffel@gmail.com")))
